/*
 *	    ____  ____  _____   ____________
 *	   / __ / __ /  _/ | / /_  __/ __
 *	  / /_/ / /_/ // //  |/ / / / / /_/ /
 *	 / ____/ _, _// // /|  / / / / _, _/
 *	/_/   /_/ |_/___/_/ |_/ /_/ /_/ |_|
 *
 */

/*
 *	Publish an app to the Formide App Store
 */

var fs 				= require('fs');
var	path			= require('path');
var archiver 		= require('archiver');
var FormideProject 	= require('./project.js');
var Task 			= require('./task.js').Task;
var FormideLogin 	= require('./login.js').FormideTask;
var FormideUtils 	= require('./utils.js');

var FormideTask 	= function() {};

FormideTask.prototype = new Task();

FormideTask.prototype.run = function( formide, callback )
{
	var project = null;
	this.formide = formide;

	try
	{
		project = FormideProject.load();
	}
	catch( e )
	{
		this.formide.fail( e.message );
	}

	var self = this;

	var login = new FormideLogin();

	login.get( formide, function( jar )
	{
		var homeDir = process.env.HOME || process.env.USERPROFILE || process.env.HOMEPATH;
		var TEMP_FILENAME = path.join(homeDir, '.formide', 'tmp', project.get('identifier') + '.zip');
		var zip = fs.createWriteStream(TEMP_FILENAME);
		var archive = archiver('zip');

		archive.pipe(zip);

		archive.bulk([
			{
				expand: true,
				cwd: './',
				src: ['**']
			}
		]);

		archive.finalize( function( err, bytes )
		{
			if( err )
			{
				return formide.fail('Error uploading: ' + err);
			}
		});

		zip.on('close', function()
		{
			console.log('\nUploading app...'.bold.green);

			var csrftoken = '';
			csrftoken = FormideUtils.retrieveCsrfToken(jar);
			var url = formide.FORMIDE_API + formide.API_APPS + '/upload/' + project.get('app_id');

			console.log( url );
		});
	});
};

exports.FormideTask = FormideTask;